@@ -89,6 +89,20 @@ class Sequence(Generic[T], Iterable[T]):
         """
         return MappingSequence(self, transform)
     
+
+    def map_indexed(self, transform: Callable[[T, int], R]) -> Sequence[R]:
+        """
+         Returns a Sequence containing the results of applying the given [transform] function
+         to each element in the original Sequence.
+
+         Example 1:
+        >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': 13}]
+        >>> it(lst).map_indexed(lambda x, i: x['age'] + i)
+        [12, 14]
+        """
+        return IndexingSequence(self).map(lambda x: transform(x.value, x.index))
+
+    
     def map_not_none(self, transform: Callable[[T], Optional[R]]) -> Sequence[R]:
         """
          Returns a Sequence containing only the non-none results of applying the given [transform] function
@@ -971,6 +985,19 @@ class Sequence(Generic[T], Iterable[T]):
         ...
     def zip(self, other: Iterable[R], transform: Callable[[T, R], V] = lambda a, b:(a, b)) -> Sequence[V]:
         return MergingSequence(self, other, transform)
+    
+    def partition(self, predicate: Callable[[T], bool]) -> Tuple[Sequence[T], Sequence[T]]:
+        """
+         Partitions the elements of the given Sequence into two groups,
+         the first group containing the elements for which the predicate returns true,
+         and the second containing the rest.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c', '2']
+        >>> it(lst).partition(lambda x: x.isalpha())
+        (['a', 'b', 'c'], ['2'])
+        """
+        return self.filter(predicate), self.filter(lambda x: not predicate(x))
 
     def to_set(self) -> Set[T]:
         """
